Skip to main contentCrate tenda_reporting
Source - ColorGenerator
- A type that can generate distinct 8-bit colors.
- Config
- A type used to configure a report
- DiagnosticConfig
- FileCache
- A
Cache that fetches Sources from the filesystem. - FnCache
- A
Cache that fetches Sources using the provided function. - Label
- A type that represents a labelled section of source code.
- Line
- A type representing a single line of a
Source. - Localization
- A type used to configure the prefixes of a report
- Report
- A type representing a diagnostic that is ready to be written to output.
- ReportBuilder
- A type used to build a
Report. - Source
- A type representing a single source that may be referred to by
Spans. - StackFrame
- A type representing a stack frame in a stack trace.
- CharSet
- Possible character sets to use when rendering diagnostics.
- Color
- Enum representing a terminal color.
- IndexType
- Possible character sets to use when rendering diagnostics.
- LabelAttach
- The attachment point of inline label arrows
- ReportKind
- A type that defines the kind of report being produced.
- Cache
- A trait implemented by
Source caches. - Diagnostic
- Fmt
- A trait used to add formatting attributes to displayable items.
- HasDiagnosticHooks
- Span
- A trait implemented by spans within a character-based source.
- sources
- Create a
Cache from a collection of ID/strings, where each corresponds to a Source.